summaryrefslogtreecommitdiffstats
path: root/perl-install/crypto.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/crypto.pm')
-rw-r--r--perl-install/crypto.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/perl-install/crypto.pm b/perl-install/crypto.pm
index 3415fa43d..7cd0b2447 100644
--- a/perl-install/crypto.pm
+++ b/perl-install/crypto.pm
@@ -102,7 +102,7 @@ sub bestMirror {
$possible[rand @possible];
}
#- hack to retrieve Mandrake Linux version...
sub version() {
require pkgs;
my $pkg = pkgs::packageByName($::o->{packages}, 'mandrake-release');
@@ -148,7 +148,7 @@ sub getPackages {
#- extract hdlist of crypto, then depslist.
require pkgs;
my $update_medium = pkgs::psUsingHdlist($prefix, 'ftp', $packages, "hdlist-updates.cz", "1u", "RPMS",
- "Updates for Mandrake Linux " . version(), 1, $fhdlist, $pubkey);
+ "Updates for Mandrakelinux " . version(), 1, $fhdlist, $pubkey);
if ($update_medium) {
log::l("read updates hdlist");
#- keep in mind where is the URL prefix used according to mirror (for install_any::install_urpmi).
@@ -102,7 +102,7 @@ sub bestMirror {
$possible[rand @possible];
}
-#- hack to retrieve Mandrake Linux version...
+#- hack to retrieve Mandrakelinux version...
sub version() {
require pkgs;